<?php
/*
Plugin Name: WEBEKI Handball Widgets: Handball Results & Rankings
Plugin URI: https://www.webeki.com/wordpress/handball-widgets/
Description: Handball Widgets plugin allows Wordpress users to quickly implement handball data like various table rankings and match results by competition into their WP posts and pages by using simple shortcodes.
Version: 1.0
Author: Webeki.com
Author URI: www.webeki.com
*/
class Codended_handswidget
{
	function install()
	{
		$this->setupTables();
		$this->importCSVLeague();
	}
	function deactivate()
	{
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_handswidget_leagues';
    	$wpdb->query( "DROP TABLE IF EXISTS $table_name" );
	}

	private static function importCSVLeague(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_handswidget_leagues';
		$file_path = plugin_dir_path( __FILE__ ).'LeagueExport.csv';
		$handle = fopen($file_path, 'r');
		$data = fgetcsv($handle, 1000, ',');
		while (($data = fgetcsv($handle, 1000, ',')) !== FALSE) {		
			$inserted = $wpdb->insert($table_name, array(
   		 	'country' => $data[0],
   		 	'LeagueName' => $data[1],
  		 	'LeagueId' => $data[2], 
  		 	'isCup' => $data[3], 
  		 	'StageName' => $data[4], 
  		 	'StageId' => $data[5], 
  		 	'GroupName' => $data[6]
		));
		}
	}
	private function setupTables(){
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();
		$table_name = $wpdb->prefix . 'ce_handswidget_leagues';
		if($wpdb->get_var("show tables like '$table_name'") != $table_name) 
			{
				$sql = "CREATE TABLE `$table_name` (
			  `id` int(11) NOT NULL AUTO_INCREMENT,
			  `country` varchar(60) NOT NULL,
			  `LeagueName` varchar(20) NOT NULL,
			  `LeagueId` varchar(20) NOT NULL,
			  `isCup` varchar(200) NOT NULL,
			  `StageName` varchar(200) NOT NULL,
			  `StageId` varchar(200) NOT NULL,
			  `GroupName` varchar(200) NOT NULL,
			  primary key (id)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1;";
			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			 dbDelta($sql);
		}
	}

	public static function onPluginReady(){
		//do_action('temp_warning',  array('Codended_handswidget_cronjob','temp_warning' ));
	}

	public function init(){
		$this->load_dependency();
		$this->load_actions();	
		$this->load_shortcodes();	
	}
	private function load_shortcodes(){
		add_shortcode( 'handballstats', array('codended_handswidget_shortcode','handballstats_shortcode'));
	}

	private function load_actions(){
		add_action( 'admin_menu', array($this,'codended_handswidget_add_admin_menu' ));
		add_action( 'admin_enqueue_scripts', array($this,'admin_enqueue_scripts') );
		add_action( 'admin_enqueue_scripts', array($this,'admin_enqueue_styles') );

		add_action( 'wp_enqueue_scripts', array($this,'frontend_enqueue_script') );

		add_action( 'admin_init', array($this,'register_settings') );
		add_action( 'wp_ajax_ce_handsw_fetchGroup', array($this,'my_ajax_fetchGroup_handler') );
		add_action( 'wp_ajax_ce_handsw_fetchStage', array($this,'my_ajax_fetchStage_handler') );
		add_action( 'wp_ajax_ce_handsw_fetchTournaments', array($this,'my_ajax_fetchTournaments_handler') );

		add_action( 'wp_ajax_ce_handsw_processPreview', array($this,'my_ajax_processPreview_handler') );
	}
	public function frontend_enqueue_script(){
		wp_enqueue_style('ce_hands_widget_css_front', plugins_url('frontend/css/style.css',__FILE__ ));
	}
	public static function register_settings (){
		register_setting( 'handsw-ce-customizesetting', 'handsraeven' );
		register_setting( 'handsw-ce-customizesetting', 'handsraodd' );
		register_setting( 'handsw-ce-customizesetting', 'handscaeven' );
		register_setting( 'handsw-ce-customizesetting', 'handscaodd' );
		register_setting( 'handsw-ce-customizesetting', 'handsfcfrcolumn' );
		register_setting( 'handsw-ce-customizesetting', 'handsfcfrrow' );
		register_setting( 'handsw-ce-customizesetting', 'handscustomizeSetting' );
	}
	public static function my_ajax_processPreview_handler(){
		$lang = $_POST['Language'];
		$datatype = $_POST['DataType'];
		$tournament = $_POST['Tournament'];
		$group = (empty($_POST['Group']))?(''):('group='.$_POST['Group']); 

		$stage = (empty($_POST['Stage']))?(''):('stage='.$_POST['Stage']);

		echo do_shortcode('[handballstats type='.$datatype.' lang='.$lang.' ranking='.$tournament.' '.$group.' '.$stage.']');
		wp_die();
	}

	public static function my_ajax_fetchGroup_handler(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_handswidget_leagues';
		$StageId = $_POST['stageId'];
		$groups = $wpdb->get_results ( "SELECT * FROM $table_name WHERE StageId = $StageId");
		$count =0;
		echo '<option>Select Group</option>';
		foreach ($groups as $group) {
			if(empty($group->GroupName)){
				continue;
			}
			echo '<option>'.$group->GroupName.'</option>';
		}
		wp_die();
	}

	public static function my_ajax_fetchStage_handler(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_handswidget_leagues';
		$LeagueId = $_POST['leagueID'];
		$stages = $wpdb->get_results ( "SELECT DISTINCT StageId , StageName FROM $table_name WHERE LeagueId = $LeagueId");
		$count =0;
		echo '<option>Select Stage</option>';
		foreach ($stages as $stage) {
			if(empty($stage->StageName)){
				continue;
			}
			echo '<option value="'.$stage->StageId.'">'.$stage->StageName.'</option>';
		}
		wp_die();
	}

	public static function my_ajax_fetchTournaments_handler(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'ce_handswidget_leagues';
		$data_type = $_POST['data_type'];

		if($data_type == 2){
			$tournaments = $wpdb->get_results ( "SELECT DISTINCT isCup , LeagueId , country , LeagueName FROM $table_name");
			foreach ($tournaments as $league) {
				echo '<option class="isLeague'.$league->isCup.'" value="'.$league->LeagueId.'">'.$league->country.' , '.$league->LeagueName.'</option>';
			}
		}else if ($data_type == 1){
			$tournaments = $wpdb->get_results ( "SELECT DISTINCT isCup , LeagueId , country , LeagueName FROM $table_name WHERE isCup='false' ");
			foreach ($tournaments as $league) {
				echo '<option class="isLeague'.$league->isCup.'" value="'.$league->LeagueId.'">'.$league->country.' , '.$league->LeagueName.'</option>';
			}
		}else{
			$tournaments = $wpdb->get_results ( "SELECT DISTINCT isCup , LeagueId , country , LeagueName FROM $table_name");
			foreach ($tournaments as $league) {
				echo '<option class="isLeague'.$league->isCup.'" value="'.$league->LeagueId.'">'.$league->country.' , '.$league->LeagueName.'</option>';
			}
		}

		wp_die();
	}

	public static function admin_enqueue_scripts($hook){
		wp_enqueue_script( 'ce_hands_widget_js', plugin_dir_url( __FILE__ ) . 'admin/js/script.js', array(), '1.0' );

	}
	
	public static function admin_enqueue_styles($hook){
		wp_enqueue_style('ce_hands_widget_css', plugins_url('admin/css/style.css',__FILE__ ));
	}
	
	private function load_dependency(){
		require_once('admin/settings.php');
		require_once('admin/customization.php');
		require_once('shortcode/main.php');
	}

	public static function codended_handswidget_add_admin_menu(  ) { 
		add_menu_page( 'Handball Scores', 'Handball Widgets', 'manage_options', 'handball-scores-widget', 'codended_handswidget_options_page' , plugins_url( 'webeki-handball-scores/images/icon.png' ) );
		add_submenu_page('handball-scores-widget', 'Customization', 'Customization', 'manage_options', 'hands-widget-customize','codended_handswidget_customization_page' );
	}
}
$Codended_handswidget = new Codended_handswidget();
register_activation_hook( __FILE__, array( $Codended_handswidget, 'install' ) );
register_deactivation_hook( __FILE__, array( $Codended_handswidget, 'deactivate' ) );
$Codended_handswidget->init();